# MultiCloudEdgeAccountInfo


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**account_credentials** | **str** |  | [optional] 
**cred_type** | **str** |  | [optional] 
**description** | **str** |  | [optional] 
**edge_account_id** | **str** |  | [optional] 
**edge_account_name** | **str** |  | [optional] 
**edge_billing_account_info** | [**MultiCloudEdgeBillingAccountInfo**](MultiCloudEdgeBillingAccountInfo.md) |  | [optional] 
**edge_location_info_list** | [**[MultiCloudEdgeLocationInfo]**](MultiCloudEdgeLocationInfo.md) |  | [optional] 
**edge_partner_ports_list** | [**[MultiCloudEdgePartnerPort]**](MultiCloudEdgePartnerPort.md) |  | [optional] 
**edge_type** | **str** |  | [optional] 
**equinix_credentials** | [**EquinixCredentials**](EquinixCredentials.md) |  | [optional] 
**megaport_credentials** | [**MegaportCredentials**](MegaportCredentials.md) |  | [optional] 
**org_name** | **str** |  | [optional] 
**region_list** | **[str]** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


